pub struct Buffer { /* private fields */ }Trait Implementations
impl DynBuffer for Buffer
Sourceimpl DynResource for Buffer
impl DynResource for Buffer
impl Send for Buffer
SAFETY:
This shared mutable data will not be accessed in a way which causes data races;
the obligation to do so is on the caller of the HAL API.
For safe code, wgpu-core validation manages appropriate access.
impl Sync for Buffer