BufferDescriptor

Struct BufferDescriptor 

pub struct BufferDescriptor<'a> {
    pub label: Label<'a>,
    pub size: BufferAddress,
    pub usage: BufferUses,
    pub memory_flags: MemoryFlags,
}

Fields

label: Label<'a>size: BufferAddress

The requested size of the buffer.

wgpu-hal may allocate more bytes than requested, if required by the platform. The actual allocation size is returned by create_buffer. Where platforms offer bounds checking, it will operate based on the allocated size, not the requested size, so other means may be necessary to prevent access beyond the original requested size. The content of newly-created buffers is undefined.

usage: BufferUsesmemory_flags: MemoryFlags