pub struct InstanceError { /* private fields */ }Expand description
Error occurring while trying to create an instance, or create a surface from an instance; typically relating to the state of the underlying graphics API or hardware.