pub struct AccelerationStructure {
raw: AccelerationStructureKHR,
buffer: Buffer,
allocation: Allocation,
compacted_size_query: Option<QueryPool>,
}Available on
vulkan only.Fields
raw: AccelerationStructureKHRbuffer: Bufferallocation: Allocationcompacted_size_query: Option<QueryPool>Implementations
Sourceimpl AccelerationStructure
impl AccelerationStructure
Sourcepub unsafe fn raw_handle(&self) -> AccelerationStructureKHR
pub unsafe fn raw_handle(&self) -> AccelerationStructureKHR
Returns the raw Vulkan acceleration structure handle.
This allows recording acceleration structure commands that wgpu-hal doesn’t
support. If those commands come from a device extension, enable it with
Adapter::open_with_callback.
For a device address, use
crate::Device::get_acceleration_structure_device_address instead.
wgpu doesn’t observe an external build, and rejects an acceleration structure
that it never built. Call wgpu::CommandEncoder::mark_acceleration_structures_built
on the encoder that recorded the build.
Safety
- The acceleration structure handle must not be manually destroyed, or used after the acceleration structure is dropped
- External work using the handle must be synchronized against
wgpu’s own reads and writes, such as compaction - An external build must not write more data than the size the acceleration structure was created with