struct DebugUtils {
extension: Instance,
messenger: DebugUtilsMessengerEXT,
callback_data: Box<DebugUtilsMessengerUserData>,
}Available on
vulkan only.Fields
extension: Instancemessenger: DebugUtilsMessengerEXTcallback_data: Box<DebugUtilsMessengerUserData>Owning pointer to the debug messenger callback user data.
InstanceShared::drop destroys the debug messenger before
dropping this, so the callback should never receive a dangling
user data pointer.