destroy_swapchain_semaphores

Function destroy_swapchain_semaphores 

fn destroy_swapchain_semaphores(
    acquire_semaphores: &mut Vec<Arc<Mutex<SwapchainAcquireSemaphore>>>,
    present_semaphores: &mut Vec<Arc<Mutex<SwapchainPresentSemaphores>>>,
    device: &Device,
)
Available on vulkan only.
Destroy the swapchain semaphores that are no longer referenced by a live surface texture. A still-referenced semaphore is skipped, as the texture may still submit work using it.

The vectors are drained.