pub struct Adapter { /* private fields */ }Available on
gles only.Implementations
Sourceimpl Adapter
impl Adapter
Sourcepub unsafe fn new_external(
fun: impl FnMut(&str) -> *const c_void,
options: GlBackendOptions,
) -> Option<ExposedAdapter<Api>>
Available on neither Windows nor webgl.
pub unsafe fn new_external( fun: impl FnMut(&str) -> *const c_void, options: GlBackendOptions, ) -> Option<ExposedAdapter<Api>>
webgl.Creates a new external adapter using the specified loader function.
Safety
- The underlying OpenGL ES context must be current.
- The underlying OpenGL ES context must be current when interfacing with any objects returned by wgpu-hal from this adapter.
- The underlying OpenGL ES context must be current when dropping this adapter and when dropping any objects returned from this adapter.
pub fn adapter_context(&self) -> &AdapterContext
Available on neither Windows nor
webgl.Trait Implementations
Sourceimpl Adapter for Adapter
impl Adapter for Adapter
type A = Api
unsafe fn open( &self, features: Features, _limits: &Limits, _memory_hints: &MemoryHints, ) -> Result<OpenDevice<Api>, DeviceError>
Sourceunsafe fn texture_format_capabilities(
&self,
format: TextureFormat,
) -> TextureFormatCapabilities
unsafe fn texture_format_capabilities( &self, format: TextureFormat, ) -> TextureFormatCapabilities
Return the set of supported capabilities for a texture format.
Sourceunsafe fn surface_capabilities(
&self,
surface: &Surface,
) -> Option<SurfaceCapabilities>
unsafe fn surface_capabilities( &self, surface: &Surface, ) -> Option<SurfaceCapabilities>
Returns the capabilities of working with a specified surface. Read more
Sourceunsafe fn get_presentation_timestamp(&self) -> PresentationTimestamp
unsafe fn get_presentation_timestamp(&self) -> PresentationTimestamp
Creates a
PresentationTimestamp using the adapter’s WSI.Sourcefn get_ordered_buffer_usages(&self) -> BufferUses
fn get_ordered_buffer_usages(&self) -> BufferUses
The combination of all usages that the are guaranteed to be be ordered by the hardware.
If a usage is ordered, then if the buffer state doesn’t change between draw calls,
there are no barriers needed for synchronization.
Sourcefn get_ordered_texture_usages(&self) -> TextureUses
fn get_ordered_texture_usages(&self) -> TextureUses
The combination of all usages that the are guaranteed to be be ordered by the hardware.
If a usage is ordered, then if the buffer state doesn’t change between draw calls,
there are no barriers needed for synchronization.
Sourceimpl DynResource for Adapter
impl DynResource for Adapter
impl Send for Adapter
Available on
send_sync only.impl Sync for Adapter
Available on
send_sync only.Auto Trait Implementations
impl Freeze for Adapter
impl !RefUnwindSafe for Adapter
impl Unpin for Adapter
impl UnsafeUnpin for Adapter
impl !UnwindSafe for Adapter