pub struct BufferDescriptor<'a> {
pub label: Label<'a>,
pub size: BufferAddress,
pub usage: BufferUses,
pub memory_flags: MemoryFlags,
}Fields
label: Label<'a>size: BufferAddressThe requested size of the buffer.
wgpu-hal may allocate more bytes than requested, if required by the
platform. The actual allocation size is returned by create_buffer.
Where platforms offer bounds checking, it will operate based on the
allocated size, not the requested size, so other means may be necessary
to prevent access beyond the original requested size. The content of
newly-created buffers is undefined.
usage: BufferUsesmemory_flags: MemoryFlagsTrait Implementations
Sourceimpl<'a> Clone for BufferDescriptor<'a>
impl<'a> Clone for BufferDescriptor<'a>
Sourcefn clone(&self) -> BufferDescriptor<'a>
fn clone(&self) -> BufferDescriptor<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<'a> Freeze for BufferDescriptor<'a>
impl<'a> RefUnwindSafe for BufferDescriptor<'a>
impl<'a> Send for BufferDescriptor<'a>
impl<'a> Sync for BufferDescriptor<'a>
impl<'a> Unpin for BufferDescriptor<'a>
impl<'a> UnwindSafe for BufferDescriptor<'a>