RayTracingPipelineDescriptor

Struct RayTracingPipelineDescriptor 

pub struct RayTracingPipelineDescriptor<'a, Pl: DynPipelineLayout + ?Sized, M: DynShaderModule + ?Sized, Pc: DynPipelineCache + ?Sized> {
    pub label: Label<'a>,
    pub layout: &'a Pl,
    pub ray_generation: ProgrammableStage<'a, M>,
    pub miss: ProgrammableStage<'a, M>,
    pub intersection: &'a [RayObjectIntersectionState<'a, M>],
    pub max_recursion_depth: u32,
    pub cache: Option<&'a Pc>,
}
Describes a ray tracing pipeline.

Fields

label: Label<'a>layout: &'a Pl

The layout of bind groups for this pipeline.

ray_generation: ProgrammableStage<'a, M>

The ray generation stage.

miss: ProgrammableStage<'a, M>

The miss stage.

intersection: &'a [RayObjectIntersectionState<'a, M>]

All the object intersection stages.

max_recursion_depth: u32

The maximum recursion depth allowed for the ray tracing (ray_generation shader counts as depth 0).

cache: Option<&'a Pc>

The cache which will be used and filled when compiling this pipeline