pub struct DescriptorCounts {
pub sampler: u32,
pub sampled_image: u32,
pub storage_image: u32,
pub uniform_buffer: u32,
pub uniform_buffer_dynamic: u32,
pub storage_buffer: u32,
pub storage_buffer_dynamic: u32,
pub acceleration_structure: u32,
}Available on
vulkan only.Expand description
The dynamic counts are tracked separately since dynamic textures/buffers have distinct descriptor types compared to their non-dynamic counterparts.
Fields
sampler: u32sampled_image: u32storage_image: u32uniform_buffer: u32uniform_buffer_dynamic: u32storage_buffer: u32storage_buffer_dynamic: u32acceleration_structure: u32Implementations