pub struct Queue {
raw: Queue,
device: Arc<DeviceShared>,
family_index: u32,
relay_semaphores: Mutex<RelaySemaphores>,
signal_semaphores: Mutex<SemaphoreList>,
}Available on
vulkan only.Fields
raw: Queuedevice: Arc<DeviceShared>family_index: u32relay_semaphores: Mutex<RelaySemaphores>signal_semaphores: Mutex<SemaphoreList>Implementations
Sourceimpl Queue
impl Queue
pub fn raw_device(&self) -> &Device
pub fn add_signal_semaphore( &self, semaphore: Semaphore, semaphore_value: Option<u64>, )
Sourcepub fn remove_signal_semaphore(&self, semaphore: Semaphore) -> bool
pub fn remove_signal_semaphore(&self, semaphore: Semaphore) -> bool
Remove semaphore from the pending signal list if it is still present.
Returns true if the semaphore was found and removed. If the submit
already consumed it, this is a harmless no-op that returns false.