pub(crate) type SynchronizedFence = Arc<Fence>;Available on
vulkan only.Expand description
A shared fence type. The arc is expect to have a ref-count of one once a function has finished being called
A fence should have access synchronised as fence resetting might happen at any point. Resetting checks the ref-count
of the fence, so instead of copying the fence, it should have its Arc container cloned which shows not to reset
this fence as it is being used.
Aliased Type
pub(crate) struct SynchronizedFence { /* private fields */ }